pub enum QueryNode {
MatchAllDocs,
MatchNoDocs,
AttributeExists {
attr: String,
},
AttributeMissing {
attr: String,
},
AttributeRange {
attr: String,
lower: ComparisonValue,
lower_inclusive: bool,
upper: ComparisonValue,
upper_inclusive: bool,
},
AttributeComparison {
attr: String,
comparator: Comparison,
value: ComparisonValue,
},
AttributeTerm {
attr: String,
value: String,
},
QuotedAttribute {
attr: String,
phrase: String,
},
AttributePrefix {
attr: String,
prefix: String,
},
AttributeWildcard {
attr: String,
wildcard: String,
},
NegatedNode {
node: Box<QueryNode>,
},
Boolean {
oper: BooleanType,
nodes: Vec<QueryNode>,
},
}Expand description
QueryNodes represent specific search criteria to be enforced.
Variants
MatchAllDocs
Match all documents.
MatchNoDocs
Match no documents.
AttributeExists
Validate existence of an attribute within a document.
AttributeMissing
Validate lack of an attribute within a document.
AttributeRange
Match an attribute against a specific range of values.
AttributeComparison
Compare an attribute against a single value (greater/less than operations).
AttributeTerm
Search for an attribute that matches a specific term.
QuotedAttribute
Search for an attribute that matches a specific quoted phrase.
AttributePrefix
Search for an attribute whose value matches against a specific prefix.
AttributeWildcard
Search for an attribute that matches a wildcard or glob string.
NegatedNode
Container node denoting negation of the QueryNode within.
Boolean
Container node for compound Boolean operations.
Implementations
Sourceimpl QueryNode
impl QueryNode
Sourcepub fn build_matcher<V, F>(
&self,
filter: &F,
) -> Result<Box<dyn Matcher<V>>, PathParseError>
pub fn build_matcher<V, F>( &self, filter: &F, ) -> Result<Box<dyn Matcher<V>>, PathParseError>
Build a filter by parsing a Datadog Search Syntax QueryNode, and invoking the appropriate
method on a Filter + Resolver implementation to determine the matching logic. Each method
returns a Matcher<V> which is intended to be invoked at runtime. F should implement both
Fielder + Filter in order to applying any required caching which may affect the operation
of a filter method. This function is intended to be used at boot-time and NOT in a hot path!
Errors
Will return Err if the query contains an invalid path.
Sourceimpl QueryNode
impl QueryNode
Sourcepub fn to_lucene(&self) -> String
pub fn to_lucene(&self) -> String
Returns a string representing this node in Lucene query formatting.
pub fn lucene_escape(input: &str) -> String
Sourcepub fn new_boolean(conjunction: BooleanType, nodes: Vec<QueryNode>) -> QueryNode
pub fn new_boolean(conjunction: BooleanType, nodes: Vec<QueryNode>) -> QueryNode
Group a list of nodes into a single node, using the given conjunction. If the group has only one node, return a clone of that node.